@@ -1,5 +1,5 @@
 package XML::CompareML::Base;
-$XML::CompareML::Base::VERSION = '0.2.11';
+$XML::CompareML::Base::VERSION = '0.2.12';
 use strict;
 use warnings;
 
@@ -8,7 +8,7 @@ use XML::LibXML;
 
 use XML::CompareML::DTD::Generate;
 
-use base qw(Class::Accessor);
+use parent qw(Class::Accessor);
 
 __PACKAGE__->mk_accessors( qw(_timestamp root_elem impls_indexes impls_names),
     qw(parser dom), );
@@ -259,7 +259,7 @@ XML::CompareML::Base - base class for the CompareML-to-something converters.
 
 =head1 VERSION
 
-version 0.2.11
+version 0.2.12
 
 =head1 SYNOPSIS
 
@@ -267,7 +267,7 @@ see L<XML::CompareML>.
 
 =head1 VERSION
 
-version 0.2.11
+version 0.2.12
 
 =head1 METHODS
 
