@@ -1,12 +1,12 @@
 package XML::CompareML::DocBook;
-$XML::CompareML::DocBook::VERSION = '0.2.11';
+$XML::CompareML::DocBook::VERSION = '0.2.12';
 use strict;
 use warnings;
 
 
 use XML::LibXML::Common qw(:w3c);
 
-use base 'XML::CompareML::Base';
+use parent 'XML::CompareML::Base';
 
 sub _print_header
 {
@@ -197,7 +197,7 @@ XML::CompareML::DocBook - convert CompareML to DocBook
 
 =head1 VERSION
 
-version 0.2.11
+version 0.2.12
 
 =head1 SYNOPSIS
 
@@ -205,7 +205,7 @@ See L<XML::CompareXML>.
 
 =head1 VERSION
 
-version 0.2.11
+version 0.2.12
 
 =head1 AUTHOR
 
