@@ -1,5 +1,5 @@
 package XML::CompareML::HTML;
-$XML::CompareML::HTML::VERSION = '0.2.11';
+$XML::CompareML::HTML::VERSION = '0.2.12';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ use XML::LibXSLT;
 
 use XML::CompareML::ConfigData;
 
-use base 'XML::CompareML::Base';
+use parent 'XML::CompareML::Base';
 
 __PACKAGE__->mk_accessors(
     qw(
@@ -109,7 +109,7 @@ XML::CompareML::HTML - convert CompareML to XHTML
 
 =head1 VERSION
 
-version 0.2.11
+version 0.2.12
 
 =head1 SYNOPSIS
 
@@ -141,7 +141,7 @@ Do the actual processing using the XSLT stylesheet.
 
 =head1 VERSION
 
-version 0.2.11
+version 0.2.12
 
 =head1 METHODS
 
